import fs from 'node:fs';
import path from 'node:path';
import { createRequire } from 'node:module';
import chalk from 'chalk-template';
import { getUrl, download } from './asset.js';
const require = createRequire(import.meta.url);
// eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
export const { version: versionFromPackageJson, } = require('../package.json');
export function tagFromVersion(version) {
    return `v${version}`;
}
export async function install({ version = versionFromPackageJson, destDir = process.env.HASURA_CLI_DEST_DIR || '.', // default to project root,
fileName = process.env.HASURA_CLI_DEST_FILENAME || 'hasura', platform = process.platform, verbose = false, } = {}) {
    const tag = tagFromVersion(version);
    const url = getUrl(tag);
    const log = (msg) => {
        if (verbose) {
            console.log(msg);
        }
    };
    log(chalk `
{bold.bgGreen.black hasura-cli}@{green ${versionFromPackageJson}}
{blue Downloading} {bold Hasura CLI binary} {green ${tag}} from {bold ${url}}
`);
    const adjustedFileName = platform === 'win32' && !fileName.endsWith('.exe')
        ? `${fileName}.exe`
        : fileName;
    const dest = await download({
        url,
        destDir,
        fileName: adjustedFileName,
    });
    if (platform === 'win32') {
        fs.unlinkSync(path.resolve(destDir, 'hasura'));
    }
    log(chalk `
{bold.bgGreen.black hasura-cli}@{green ${versionFromPackageJson}}
{green Installed!} {bold Hasura CLI binary} {green ${tag}} is installed to {bold ${dest}}
`);
    return dest;
}
//# sourceMappingURL=install.js.map